/*************************************************************************************
 *  Copyright (C) 2015 by Samuel Gaist <samuel.gaist@edeltech.ch                     *
 *                                                                                   *
 *  This library is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU Lesser General Public                       *
 *  License as published by the Free Software Foundation; either                     *
 *  version 2.1 of the License, or (at your option) any later version.               *
 *                                                                                   *
 *  This library is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
 *  Lesser General Public License for more details.                                  *
 *                                                                                   *
 *  You should have received a copy of the GNU Lesser General Public                 *
 *  License along with this library; if not, write to the Free Software              *
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
 *************************************************************************************/

#ifndef PAM_DARWIN_H
#define PAM_DARWIN_H

#include <security/pam_modules.h>

void pam_vsyslog(const pam_handle_t *ph, int priority, const char *fmt, va_list args);
void pam_syslog(const pam_handle_t *ph, int priority, const char *fmt, ...);

#endif
